pub fn decode_binary_frame(
input: &[u8],
) -> Result<(DecodedBinaryFrame, &[u8]), BinaryDecodeError>Expand description
Decodes the next binary frame and returns the remaining input.
This is useful when reading a stream containing multiple concatenated metadata and event frames.